@@ -1,31 +1,32 @@
 import pytest
+
 sa = pytest.importorskip("sqlalchemy")
 
 import os
 import responses
 import flask
-from lazy import lazy
 from flask_sqlalchemy import SQLAlchemy
 from sqlalchemy import event
-from sqlalchemy.orm.exc import NoResultFound
 from flask_caching import Cache
 from flask_login import LoginManager, UserMixin, current_user, login_user, logout_user
 from flask_dance.consumer import OAuth2ConsumerBlueprint, oauth_authorized, oauth_error
-from flask_dance.consumer.backend.sqla import OAuthConsumerMixin, SQLAlchemyBackend
+from flask_dance.consumer.storage.sqla import OAuthConsumerMixin, SQLAlchemyStorage
+
 try:
     import blinker
 except ImportError:
     blinker = None
 requires_blinker = pytest.mark.skipif(not blinker, reason="requires blinker")
 
-pytestmark = [
-    pytest.mark.usefixtures("responses"),
-]
+pytestmark = [pytest.mark.usefixtures("responses")]
 
 
 @pytest.fixture
 def blueprint():
-    bp = OAuth2ConsumerBlueprint("test-service", __name__,
+    "Make a OAuth2 blueprint for a fictional OAuth provider"
+    bp = OAuth2ConsumerBlueprint(
+        "test-service",
+        __name__,
         client_id="client_id",
         client_secret="client_secret",
         state="random-string",
@@ -44,13 +45,16 @@ def blueprint():
 
 @pytest.fixture
 def db():
+    "Make a Flask-SQLAlchemy instance"
     return SQLAlchemy()
 
 
 @pytest.fixture
 def app(blueprint, db, request):
+    "Make a Flask app, attach Flask-SQLAlchemy, and establish an app context"
     app = flask.Flask(__name__)
     app.config["SQLALCHEMY_DATABASE_URI"] = os.environ.get("DATABASE_URI", "sqlite://")
+    app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
     app.config["CACHE_TYPE"] = "simple"
     app.secret_key = "secret"
     app.register_blueprint(blueprint, url_prefix="/login")
@@ -67,6 +71,7 @@ class record_queries(object):
     A context manager for recording the SQLAlchemy queries that were executed
     in a given context block.
     """
+
     def __init__(self, target, identifier="before_cursor_execute"):
         self.target = target
         self.identifier = identifier
@@ -83,17 +88,18 @@ class record_queries(object):
         event.remove(self.target, self.identifier, self.record_query)
 
 
-def test_sqla_backend_without_user(app, db, blueprint, request):
-
+def test_sqla_storage_without_user(app, db, blueprint, request):
     class OAuth(OAuthConsumerMixin, db.Model):
         pass
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     with record_queries(db.engine) as queries:
@@ -130,9 +136,11 @@ def test_sqla_model_repr(app, db, request):
         pass
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     o = MyAwesomeOAuth()
@@ -148,8 +156,7 @@ def test_sqla_model_repr(app, db, request):
     assert "secret" not in repr(o)
 
 
-def test_sqla_backend(app, db, blueprint, request):
-
+def test_sqla_storage(app, db, blueprint, request):
     class User(db.Model):
         id = db.Column(db.Integer, primary_key=True)
         name = db.Column(db.String(80))
@@ -159,9 +166,11 @@ def test_sqla_backend(app, db, blueprint, request):
         user = db.relationship(User)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # for now, we'll assume that Alice is the only user
@@ -171,7 +180,7 @@ def test_sqla_backend(app, db, blueprint, request):
     # load alice's ID -- this issues a database query
     alice.id
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session, user=alice)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session, user=alice)
 
     with record_queries(db.engine) as queries:
         with app.test_client() as client:
@@ -205,7 +214,6 @@ def test_sqla_backend(app, db, blueprint, request):
 
 
 def test_sqla_load_token_for_user(app, db, blueprint, request):
-
     class User(db.Model):
         id = db.Column(db.Integer, primary_key=True)
         name = db.Column(db.String(80))
@@ -215,13 +223,15 @@ def test_sqla_load_token_for_user(app, db, blueprint, request):
         user = db.relationship(User)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # set token storage
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session)
 
     # make users and OAuth tokens for several people
     alice = User(name="Alice")
@@ -274,6 +284,7 @@ def test_sqla_load_token_for_user(app, db, blueprint, request):
     assert sess.token == alice_token
     assert blueprint.token == alice_token
 
+
 def test_sqla_flask_login(app, db, blueprint, request):
     login_manager = LoginManager(app)
 
@@ -285,12 +296,14 @@ def test_sqla_flask_login(app, db, blueprint, request):
         user_id = db.Column(db.Integer, db.ForeignKey(User.id))
         user = db.relationship(User)
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session, user=current_user)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session, user=current_user)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # create some users
@@ -311,7 +324,7 @@ def test_sqla_flask_login(app, db, blueprint, request):
             with client.session_transaction() as sess:
                 sess["test-service_oauth_state"] = "random-string"
                 # set alice as the logged in user
-                sess["user_id"] = u1.id
+                sess["_user_id"] = u1.id
             # make the request
             resp = client.get(
                 "/login/test-service/authorized?code=secret-code&state=random-string",
@@ -336,7 +349,7 @@ def test_sqla_flask_login(app, db, blueprint, request):
             with client.session_transaction() as sess:
                 sess["test-service_oauth_state"] = "random-string"
                 # set bob as the logged in user
-                sess["user_id"] = u2.id
+                sess["_user_id"] = u2.id
             # make the request
             resp = client.get(
                 "/login/test-service/authorized?code=secret-code&state=random-string",
@@ -381,12 +394,14 @@ def test_sqla_flask_login_misconfigured(app, db, blueprint, request):
         user_id = db.Column(db.Integer, db.ForeignKey(User.id))
         user = db.relationship(User)
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session, user=current_user)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session, user=current_user)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # configure login manager
@@ -395,6 +410,7 @@ def test_sqla_flask_login_misconfigured(app, db, blueprint, request):
         return User.query.get(userid)
 
     calls = []
+
     def callback(*args, **kwargs):
         calls.append((args, kwargs))
 
@@ -416,9 +432,9 @@ def test_sqla_flask_login_misconfigured(app, db, blueprint, request):
 
     assert len(calls) == 1
     assert calls[0][0] == (blueprint,)
-    error = calls[0][1]['error']
+    error = calls[0][1]["error"]
     assert isinstance(error, ValueError)
-    assert str(error) == 'Cannot set OAuth token without an associated user'
+    assert str(error) == "Cannot set OAuth token without an associated user"
 
 
 @requires_blinker
@@ -433,12 +449,14 @@ def test_sqla_flask_login_anon_to_authed(app, db, blueprint, request):
         user_id = db.Column(db.Integer, db.ForeignKey(User.id))
         user = db.relationship(User)
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session, user=current_user)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session, user=current_user)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # configure login manager
@@ -462,9 +480,7 @@ def test_sqla_flask_login_anon_to_authed(app, db, blueprint, request):
 
     # mock out the `/user` API call
     responses.add(
-        responses.GET,
-        "https://example.com/user",
-        body='{"name":"josephine"}',
+        responses.GET, "https://example.com/user", body='{"name":"josephine"}'
     )
 
     with record_queries(db.engine) as queries:
@@ -502,10 +518,7 @@ def test_sqla_flask_login_anon_to_authed(app, db, blueprint, request):
 
 def test_sqla_flask_login_preload_logged_in_user(app, db, blueprint, request):
     # need a URL to hit, so that tokens will be loaded, but result is irrelevant
-    responses.add(
-        responses.GET,
-        "https://example.com/noop",
-    )
+    responses.add(responses.GET, "https://example.com/noop")
 
     login_manager = LoginManager(app)
 
@@ -517,12 +530,14 @@ def test_sqla_flask_login_preload_logged_in_user(app, db, blueprint, request):
         user_id = db.Column(db.Integer, db.ForeignKey(User.id))
         user = db.relationship(User)
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session, user=current_user)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session, user=current_user)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # create some users, and tokens for some of them
@@ -577,10 +592,7 @@ def test_sqla_flask_login_preload_logged_in_user(app, db, blueprint, request):
 
 def test_sqla_flask_login_no_user_required(app, db, blueprint, request):
     # need a URL to hit, so that tokens will be loaded, but result is irrelevant
-    responses.add(
-        responses.GET,
-        "https://example.com/noop",
-    )
+    responses.add(responses.GET, "https://example.com/noop")
 
     login_manager = LoginManager(app)
 
@@ -592,14 +604,16 @@ def test_sqla_flask_login_no_user_required(app, db, blueprint, request):
         user_id = db.Column(db.Integer, db.ForeignKey(User.id))
         user = db.relationship(User)
 
-    blueprint.backend = SQLAlchemyBackend(
-        OAuth, db.session, user=current_user, user_required=False,
+    blueprint.storage = SQLAlchemyStorage(
+        OAuth, db.session, user=current_user, user_required=False
     )
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # configure login manager
@@ -621,26 +635,23 @@ def test_sqla_flask_login_no_user_required(app, db, blueprint, request):
 
 
 def test_sqla_delete_token(app, db, blueprint, request):
-
     class OAuth(OAuthConsumerMixin, db.Model):
         pass
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # Create an existing OAuth token for the service
     existing = OAuth(
         provider="test-service",
-        token={
-            "access_token": "something",
-            "token_type": "bearer",
-            "scope": ["blah"],
-        },
+        token={"access_token": "something", "token_type": "bearer", "scope": ["blah"]},
     )
     db.session.add(existing)
     db.session.commit()
@@ -657,26 +668,23 @@ def test_sqla_delete_token(app, db, blueprint, request):
 
 
 def test_sqla_overwrite_token(app, db, blueprint, request):
-
     class OAuth(OAuthConsumerMixin, db.Model):
         pass
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     # Create an existing OAuth token for the service
     existing = OAuth(
         provider="test-service",
-        token={
-            "access_token": "something",
-            "token_type": "bearer",
-            "scope": ["blah"],
-        },
+        token={"access_token": "something", "token_type": "bearer", "scope": ["blah"]},
     )
     db.session.add(existing)
     db.session.commit()
@@ -717,12 +725,14 @@ def test_sqla_cache(app, db, blueprint, request):
     class OAuth(OAuthConsumerMixin, db.Model):
         pass
 
-    blueprint.backend = SQLAlchemyBackend(OAuth, db.session, cache=cache)
+    blueprint.storage = SQLAlchemyStorage(OAuth, db.session, cache=cache)
 
     db.create_all()
+
     def done():
         db.session.remove()
         db.drop_all()
+
     request.addfinalizer(done)
 
     with record_queries(db.engine) as queries:
@@ -741,11 +751,7 @@ def test_sqla_cache(app, db, blueprint, request):
 
     assert len(queries) == 2
 
-    expected_token = {
-        "access_token": "foobar",
-        "token_type": "bearer",
-        "scope": [""],
-    }
+    expected_token = {"access_token": "foobar", "token_type": "bearer", "scope": [""]}
 
     # check the database
     authorizations = OAuth.query.all()
